#################################################################################################################
### Trevelline et al. 2019 
### A bird’s eye view of phylosymbiosis: weak but significant signatures of phylosymbiosis among all 15 species of cranes
### Brian K. Trevelline 
### Last Modified: 12 July 2019
#################################################################################################################
#################################################################################################################
###Phylogenetic patterns of crane gut microbial alpha diversity
library(phylosignal)
library(phylobase)

cranes.data <- read.csv('SupplementalDataS1.csv')

df.alpha <- aggregate(ASV_Richness~Species, FUN = 'mean', data = cranes.data)
df.faith <- aggregate(FaithsDiversity~Species, FUN = 'mean', data = cranes.data)
df.density <- aggregate(MicrobialDensityDividedBy10000000~Species, FUN = 'mean', data = cranes.data)
df.alpha$FaithsDiversity <- df.faith$FaithsDiversity
df.alpha$MicrobialDensityDividedBy10000000 <- df.density$MicrobialDensityDividedBy10000000

df.alpha.sd <- aggregate(ASV_Richness~Species, FUN = 'sd', data = cranes.data)
df.faith.sd <- aggregate(FaithsDiversity~Species, FUN = 'sd', data = cranes.data)
df.density.sd <- aggregate(MicrobialDensityDividedBy10000000~Species, FUN = 'sd', data = cranes.data)
df.alpha.sd$FaithsDiversity <- df.faith.sd$FaithsDiversity
df.alpha.sd$MicrobialDensityDividedBy10000000 <- df.density.sd$MicrobialDensityDividedBy10000000

cranes <- read.p4d(phylo.file = "CraneTree.newick", data.file = "TipLabels.csv")
data <- df.alpha 
rownames(data) <- df.alpha$Species
data <- data[,-1]
rownames(data)

error <- df.alpha.sd
rownames(error) <- df.alpha.sd$Species
error <- error[,-1]
rownames(error)

tipData(cranes) <- data
tdata(cranes)

crane.tip.labels <- c("Balearica pavonina",
                      "Balearica regulorum",
                      "Leucogeranus leucogeranus",
                      "Grus canadensis",
                      "Grus vipio",
                      "Grus rubicunda",
                      "Grus antigone",
                      "Bugeranus carunculatus",
                      "Anthropoides paradiseus",
                      "Anthropoides virgo",
                      "Grus japonensis",
                      "Grus americana",
                      "Grus grus",
                      "Grus monacha",
                      "Grus nigricollis")

dotplot.phylo4d(cranes, 
                center = FALSE, 
                error.bar.inf = error, 
                error.bar.sup = error,
                tree.ladderize = TRUE, 
                scale = FALSE,
                grid.lty = 'blank', 
                grid.col = 'transparent', 
                trait.bg.col = 'transparent', 
                trait.labels = c("Observed OTUs", "Faith's Diversity", expression(paste("Bacterial Abundance (x10"^"7",")", sep = ""))),
                tip.labels = sub("_"," ", crane.tip.labels),
                tip.cex = 2,
                trait.cex = 1.5,
                dot.cex = 5,
                show.box = TRUE)

phylo.cranes <- phyloSignal(cranes)
lipa.cranes <- lipaMoran(cranes, as.p4d = FALSE, alternative = 'two-sided')

#################################################################################################################
### UPGMA clustering for phylosymbiosis test ####################################################################
### Standard pipeline with rarefaction ##########################################################################
library(ggplot2)
library(phyloseq)
library(vegan)
library(pairwiseAdonis)
library(ape)
library(reshape2)

otu.table = read.csv("OtuTable.csv", sep = ",", row.names = 1)
head(otu.table)
otu.table = as.matrix(otu.table)

taxonomy = read.csv("Taxonomy.csv", sep = ",", row.names = 1)
head(taxonomy)
taxonomy = as.matrix(taxonomy)

metadata = read.csv("cranes-metadata.csv", sep = ",", row.names = 1)
head(metadata)

phy.tree <- read_tree("rooted-tree.nwk") #Import rooted tree from QIIME

OTU = otu_table(otu.table, taxa_are_rows = TRUE) #Import otu.table as Phyloseq object
TAX = tax_table(taxonomy) #Import taxonomy as Phyloseq object
META = sample_data(metadata) #Import metadata as Phyloseq object

#Check that OTUs have the same name across files
taxa_names(TAX)
taxa_names(OTU)
taxa_names(phy.tree)

#Check that samples have the same name across files
sample_names(OTU)
sample_names(META)

physeq = phyloseq(OTU, TAX, META, phy.tree) #Merge all files into a single Phyloseq object.

#Rareify 
otu.table.read.counts <- colSums(otu.table)
rarefaction.depth <- min(otu.table.read.counts)

physeq.rarefied <- rarefy_even_depth(physeq, sample.size = rarefaction.depth, replace = FALSE, rngseed = 711)

###

physeq.for.upgma.table = as(otu_table(physeq.rarefied), "matrix")
physeq.for.upgma.table <- t(physeq.for.upgma.table)
physeq.for.upgma.table <- as.data.frame(physeq.for.upgma.table)

physeq.for.upgma.table$SampleID <- row.names(physeq.for.upgma.table)
physeq.for.upgma.table$Species <- metadata$Species[match(metadata$Description, physeq.for.upgma.table$SampleID)]

#FORMAT DATA
physeq.for.upgma.table.molten <- melt(physeq.for.upgma.table, id.var = c("SampleID", "Species"), var = 'OTUID')

#COMPUTE AVERAGES
physeq.for.upgma.table.mean <- aggregate(value~Species * OTUID, FUN = 'mean', data = physeq.for.upgma.table.molten)
physeq.for.upgma.table.mean$value <- ceiling(physeq.for.upgma.table.mean$value) #Round values up (mean-ceiling)
physeq.for.upgma.table.mean.casted <- dcast(physeq.for.upgma.table.mean, OTUID ~ Species)
write.csv(physeq.for.upgma.table.mean.casted, "physeq.for.upgma.table.mean.casted.csv")

otu.table = read.csv("physeq.for.upgma.table.mean.casted.csv", sep = ',', row.names = 1) # must delete first column of numbers before import
head(otu.table)
otu.table = as.matrix(otu.table)

metadata.by.species = read.csv("cranes-metadata-by-species.csv", sep = ",", row.names = 1)
head(metadata.by.species)

OTU = otu_table(otu.table, taxa_are_rows = TRUE) #Import physeq.for.upgma.mean.casted as Phyloseq object
META = sample_data(metadata.by.species) #Import metadata as Phyloseq object
phy.tree <- read_tree("rooted-tree-trimmed-after-rarefaction.nwk") #Import rooted tree from QIIME. Must be trimmed of all exluded OTUs.

physeq.for.upgma.mean = phyloseq(OTU, TAX, META, phy.tree) #Merge all files into a single Phyloseq object.

#Bray-Curtis
physeq.for.upgma.mean.rarefied.bray.dist <- distance(physeq.for.upgma.mean, method = "bray") #Generate distance matrix
physeq.for.upgma.mean.rarefied.bray.dist.UPGMA <- hclust(physeq.for.upgma.mean.rarefied.bray.dist, method = "average")
plot(physeq.for.upgma.mean.rarefied.bray.dist.UPGMA)
physeq.for.upgma.mean.rarefied.bray.dist.UPGMA <- as.phylo(physeq.for.upgma.mean.rarefied.bray.dist.UPGMA)
write.tree(physeq.for.upgma.mean.rarefied.bray.dist.UPGMA, "physeq.rarefied.bray.dist.UPGMA.newick")

#Unweighted
physeq.for.upgma.mean.rarefied.unweighted.dist <- distance(physeq.for.upgma.mean, method = "uunifrac") #Generate distance matrix
physeq.for.upgma.mean.rarefied.unweighted.dist.UPGMA <- hclust(physeq.for.upgma.mean.rarefied.unweighted.dist, method = "average")
plot(physeq.for.upgma.mean.rarefied.unweighted.dist.UPGMA)
physeq.for.upgma.mean.rarefied.unweighted.dist.UPGMA <- as.phylo(physeq.for.upgma.mean.rarefied.unweighted.dist.UPGMA)
write.tree(physeq.for.upgma.mean.rarefied.unweighted.dist.UPGMA, "physeq.rarefied.unweighted.dist.UPGMA.newick")

#Weighted
physeq.for.upgma.mean.rarefied.weighted.dist <- distance(physeq.for.upgma.mean, method = "wunifrac") #Generate distance matrix
physeq.for.upgma.mean.rarefied.weighted.dist.UPGMA <- hclust(physeq.for.upgma.mean.rarefied.weighted.dist, method = "average")
plot(physeq.for.upgma.mean.rarefied.weighted.dist.UPGMA)
physeq.for.upgma.mean.rarefied.weighted.dist.UPGMA <- as.phylo(physeq.for.upgma.mean.rarefied.weighted.dist.UPGMA)
write.tree(physeq.for.upgma.mean.rarefied.weighted.dist.UPGMA, "physeq.rarefied.weighted.dist.UPGMA.newick")

#################################################################################################################
### Standard pipeline + microbial density correction, no rarefaction ############################################

otu.table.flow = read.csv("OTUTableFlow.csv", sep = ",", row.names = 1)
head(otu.table.flow)
otu.table.flow = as.matrix(otu.table.flow)

taxonomy.flow = read.csv("TaxonomyFlow.csv", sep = ",", row.names = 1)
head(taxonomy.flow)
taxonomy.flow = as.matrix(taxonomy.flow)

metadata.by.species = read.csv("cranes-metadata-by-species.csv", sep = ",", row.names = 1)
head(metadata.by.species)

OTU.flow = otu_table(otu.table.flow, taxa_are_rows = TRUE) #Import otu.table as Phyloseq object
TAX.flow = tax_table(taxonomy.flow) #Import taxonomy as Phyloseq object
META.flow = sample_data(metadata.by.species) #Import metadata as Phyloseq object

#Check that OTUs have the same name across files
taxa_names(TAX.flow)
taxa_names(OTU.flow)
taxa_names(phy.tree)

#Check that samples have the same name across files
sample_names(OTU.flow)
sample_names(META.flow)

phy.tree <- read_tree("rooted-tree.nwk") #Import rooted tree from QIIME. Must be trimmed of all exluded OTUs.

physeq.flow = phyloseq(OTU.flow, TAX.flow, META.flow, phy.tree) #Merge all files into a single Phyloseq object.

#Bray-Curtis
physeq.flow.bray.dist <- distance(physeq.flow, method = "bray") #Generate distance matrix
physeq.flow.bray.dist.UPGMA <- hclust(physeq.flow.bray.dist, method = "average")
physeq.flow.bray.dist.UPGMA <- as.phylo(physeq.flow.bray.dist.UPGMA)
write.tree(physeq.flow.bray.dist.UPGMA, "physeq.flow.bray.dist.UPGMA.newick")

#Unweighted
physeq.flow.unweighted.dist <- distance(physeq.flow, method = "uunifrac") #Generate distance matrix
physeq.flow.unweighted.dist.UPGMA <- hclust(physeq.flow.unweighted.dist, method = "average")
physeq.flow.unweighted.dist.UPGMA <- as.phylo(physeq.flow.unweighted.dist.UPGMA)
write.tree(physeq.flow.unweighted.dist.UPGMA, "physeq.flow.unweighted.dist.UPGMA.newick")

#Weighted
physeq.flow.weighted.dist <- distance(physeq.flow, method = "wunifrac") #Generate distance matrix
physeq.flow.weighted.dist.UPGMA <- hclust(physeq.flow.weighted.dist, method = "average")
physeq.flow.weighted.dist.UPGMA <- as.phylo(physeq.flow.weighted.dist.UPGMA)
write.tree(physeq.flow.weighted.dist.UPGMA, "physeq.flow.weighted.dist.UPGMA.newick")

### END